/**
  ******************************************************************************
  * @file    system_K1921BK01T.c
  * @author  NIIET Application Team
  * @version V1.1.0
  * @date    08-JULY-2015
  * @brief   CMSIS Cortex-M4 Device Peripheral Access Layer System Source File.
  * 
  * 1.  This file provides two functions and one global variable to be called from 
  *     user application:
  *      - SystemInit(): Setups the system clock (System clock source, PLL Multiplier
  *                      factors, AHB/APBx prescalers and Flash settings). 
  *                      This function is called at startup just after reset and 
  *                      before branch to main program. This call is made inside
  *                      the "startup_K1921BK01T.s" file.
  *
  *      - SystemCoreClock variable: Contains the core clock (HCLK), it can be used
  *                                  by the user application to setup the SysTick 
  *                                  timer or configure other parameters.
  *                                     
  *      - SystemCoreClockUpdate(): Updates the variable SystemCoreClock and must
  *                                 be called whenever the core clock is changed
  *                                 during program execution.
  *
  * 2. After each device reset the HSI (12 MHz) is used as system clock source.
  *    Then SystemInit() function is called, in "startup_K1921BK01T.s" file, to
  *    configure the system clock before to branch to main program.
  *
  * 3. If the system clock source selected by user fails to startup, the SystemInit()
  *    function will do nothing and HSI still used as system clock source. User can 
  *    add some code to deal with this issue inside the SetSysClock() function.
  *
  * 4. The default value of HSE crystal is set to 12 MHz (or 16 MHz, depedning on !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  *    the board used), refer to "HSE_VALUE" define in "K1921BK01T.h" file. 
  *    When HSE is used as system clock source, directly or through PLL, and you
  *    are using different crystal you have to adapt the HSE value to your own
  *    configuration.
  *        
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, NIIET SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2015 NIIET</center></h2>
  ******************************************************************************
  */



/** @addtogroup CMSIS
  * @{
  */

/** @addtogroup K1921BK01T_system
  * @{
  */  
  
/** @addtogroup K1921BK01T_System_Private_Includes
  * @{
  */

#include "K1921BK01T.h"
/*----------------------------------------------------------------------------
  Define clocks
 *----------------------------------------------------------------------------*/
#define __HSI             ( 8000000UL)
#define __XTAL            ( 12000000UL)    /* External Oscillator frequency    */
#define __RCGEN           ( 5000000UL)    /* Internal RC-generator frequency   */

#define __SYSTEM_CLOCK    (5*__XTAL)


/*----------------------------------------------------------------------------
  Clock Variable definitions
 *----------------------------------------------------------------------------*/
uint32_t SystemCoreClock = __SYSTEM_CLOCK;/*!< System Clock Frequency (Core Clock)*/


/*----------------------------------------------------------------------------
  Clock functions
 *----------------------------------------------------------------------------*/
void SystemCoreClockUpdate (void)            /* Get Core Clock Frequency      */
{

  SystemCoreClock = __SYSTEM_CLOCK;

}

/**
 * Initialize the system
 *
 * @param  none
 * @return none
 *
 * @brief  Setup the microcontroller system.
 *         Initialize the System.
 */
void SystemInit (void)
{
#if (__FPU_PRESENT == 1) && (__FPU_USED == 1)
    //NT_SYSTEM->CPACR = (3UL << 10*2);               /* set CP11 Full Access */
	  __asm("DSB");																				 /* Conveyor restart */
    __asm("ISB");																				 /* Conveyor restart */
  #endif

#ifdef UNALIGNED_SUPPORT_DISABLE
    NT_SYSTEM->CCR |= CCR_UNALIGN_TRP_Msk;
#endif

//  SystemCoreClock = __SYSTEM_CLOCK;

}
/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
